@@ -1,7 +1,7 @@
 package Complete;
 
-our $DATE = '2014-12-25'; # DATE
-our $VERSION = '0.07'; # VERSION
+our $DATE = '2014-12-27'; # DATE
+our $VERSION = '0.08'; # VERSION
 
 use 5.010001;
 use strict;
@@ -26,7 +26,7 @@ Complete - Convention for Complete::* modules family and common settings
 
 =head1 VERSION
 
-This document describes version 0.07 of Complete (from Perl distribution Complete), released on 2014-12-25.
+This document describes version 0.08 of Complete (from Perl distribution Complete), released on 2014-12-27.
 
 =head1 DESCRIPTION
 
@@ -193,7 +193,7 @@ All L<Complete::Path>-based modules (like L<Complete::Util>'s
 C<complete_file()>), L<Complete::Module>, or L<Complete::Riap> respect this
 setting.
 
-=head2 C<$Complete::OPT_EXP_IM_PATH> => bool (default: from COMPLETE_OPT_EXP_IM_PATH or 0)
+=head2 C<$Complete::OPT_EXP_IM_PATH> => bool (default: from COMPLETE_OPT_EXP_IM_PATH or 1)
 
 Whether to "expand intermediate paths". What is meant by this is something like
 zsh: when you type something like C<cd /h/u/b/myscript> it can be completed to
@@ -203,9 +203,46 @@ All L<Complete::Path>-based modules (like L<Complete::Util>'s
 C<complete_file()>), L<Complete::Module>, or L<Complete::Riap> respect this
 setting.
 
-Currently defaults to 0 because in the case of /foo/bar and /foo2/baz, when user
-type "/foo/b" bash will keep the user stuck at "/foo" because it is the shortest
-common substring. This is annoying.
+=head2 C<$Complete::OPT_EXP_IM_PATH_MAX_LEN> => int (default: from COMPLETE_OPT_EXP_IM_PATH_MAX_LEN or 2)
+
+Wehn OPT_EXP_IM_PATH is active, because of the way bash does completion (it cuts
+current word to the shortest common denominator of all completion candidates),
+in some cases this can be annoying because it prevents completion to be done the
+way we want. For example:
+
+ l/D/Zi/Plugi/Author<tab>
+
+if we have:
+
+ lib/Dist/Zilla/Plugin/Author/
+ lib/Dist/Zilla/PluginBundle/Author/
+
+the completion candidates are both the above, and bash cuts our word at the
+buffer to:
+
+ lib/Dist/Zilla/Plugin
+
+even if we type C</> and then Tab like this:
+
+ lib/Dist/Zilla/Plugin/<tab>
+
+bash will again cuts the buffer to become:
+
+ lib/Dist/Zilla/Plugin
+
+To work around (or compromise around) this, the setting
+C<OPT_EXP_IM_PATH_MAX_LEN> is introduced. The default is 2. So if a path element
+is over 2 characters long, expand will not be done. This means in this path:
+
+ l/D/Zi/Plugi/Author<tab>
+
+we expand C<l>, C<D>, C<Zi>, but not C<Plugi>. So to get expansion you'll have
+to write:
+
+ l/D/Zi/P/Author<tab>
+ l/D/Zi/Pl/Author<tab>
+
+which is usually fine.
 
 =head1 ENVIRONMENT
 
@@ -221,8 +258,14 @@ Set default for C<$Complete::OPT_MAP_CASE>.
 
 Set default for C<$Complete::OPT_EXP_IM_PATH>.
 
+=head2 COMPLETE_OPT_EXP_IM_PATH_MAX_LEN => int
+
+Set default for C<$Complete::OPT_EXP_IM_PATH_MAX_LEN>.
+
 =head1 TODO
 
+COMPLETE_OPT_MAX_RESULT?
+
 =head1 SEE ALSO
 
 =head1 HOMEPAGE
